@@ -1,8 +1,12 @@
 #[cfg(dbus)]
 use crate::app::konsole;
 #[cfg(dbus)]
+use crate::app::gnome_shell;
+#[cfg(dbus)]
 use crate::app::gnome_terminal;
 #[cfg(dbus)]
+use crate::app::gtk;
+#[cfg(dbus)]
 use crate::app::plasma;
 use crate::app::vscode;
 use crate::app::alacritty;
@@ -22,8 +26,13 @@ pub struct Config {
     #[cfg(dbus)]
     pub konsole: Option<konsole::Config>,
     #[cfg(dbus)]
+    #[serde(rename = "gnome-shell")]
+    pub gnome_shell: Option<gnome_shell::Config>,
+    #[cfg(dbus)]
     #[serde(rename = "gnome-terminal")]
     pub gnome_terminal: Option<gnome_terminal::Config>,
+    #[cfg(dbus)]
+    pub gtk: Option<gtk::Config>,
     pub vscode: Option<vscode::Config>,
     pub alacritty: Option<alacritty::Config>,
     pub vim: Option<vim::Config>,
